@@ -469,7 +469,7 @@ NMscanData <- function(file, col.row, use.input, merge.by.row,
            filePathSimple(file.mod)!=filePathSimple(file)) {
             mtime.mod <- file.info.mod$mtime
             
-            if(mtime.mod>testtime.lst){
+            if(length(mtime.mod) && mtime.mod>testtime.lst){
                 ## messageWrap(paste0("input control stream (",file.mod,") is newer than output control stream (",file,"). Seems like model has been edited since last run. If data sections have been edited, this can corrupt results."),
                 messageWrap("Input control stream is newer than output control stream.",
                             fun.msg=warning)
@@ -517,7 +517,7 @@ NMscanData <- function(file, col.row, use.input, merge.by.row,
             }
         
     }
-
+    
 ### Section end: Check file modification times
 
 
